from wizlib.parser import WizParser

from kwark.command import KwarkCommand
from kwark.util import load_prompt
from kwark.ai import AI


class DocCommand(KwarkCommand):
    """Summarize observations and conclusions from random text such as a
    thread, email, or notes"""

    name = 'doc'
    prompt = load_prompt(name)

    @classmethod
    def add_args(cls, parser: WizParser):
        super().add_args(parser)
        parser.add_argument('--api-key', '-k')

    def handle_vals(self):
        super().handle_vals()
        if not self.provided('api-key'):
            if key := self.app.config.get('kwark-api-anthropic-key'):
                self.api_key = key

    @KwarkCommand.wrap
    def execute(self):
        input = self.app.stream.text
        prompt = self.prompt.format(text=input)
        response = AI(self.api_key).query(prompt)
        return response
        # return f"Hello, {input}!"



from wizlib.parser import WizParser

from kwark.command import KwarkCommand
from kwark.util import load_prompt
from kwark.ai import AI


class BranchCommand(KwarkCommand):
    """Generate a git branch name from input text using AI.
    The branch name will be hyphen-separated, lowercase, starting with
    the current date in YYYYMMDD format, followed by 1-4 important words
    from the input text."""

    name = 'branch'
    prompt = load_prompt(name)

    @classmethod
    def add_args(cls, parser: WizParser):
        super().add_args(parser)
        parser.add_argument('--api-key', '-k')

    def handle_vals(self):
        super().handle_vals()
        if not self.provided('api-key'):
            if key := self.app.config.get('kwark-api-anthropic-key'):
                self.api_key = key

    @KwarkCommand.wrap
    def execute(self):
        input_text = self.app.stream.text
        if not input_text.strip():
            self.status = "Error: No input text provided"
            return

        prompt = self.prompt.format(text=input_text)
        branch_name = AI(self.api_key).query(prompt).strip()

        self.status = f"Generated branch name from input text"
        return branch_name



from anthropic import Anthropic


class AI:  # pragma: nocover

    model = 'claude-3-5-sonnet-20241022'

    def __init__(self, api_key=None):
        if api_key:
            self.client = Anthropic(api_key=api_key)
        else:
            self.client = Anthropic()

    def query(self, text):
        """Send a one-time query, no tools"""
        messages = [
            {
                "role": "user",
                "content": [
                    {
                        "type": "text",
                        "text": text
                    }
                ]
            }

        ]
        message = self.client.messages.create(
            model=self.model,
            max_tokens=4096,
            temperature=0,
            messages=messages)
        response = message.content[0].text
        return response



from wizlib.parser import WizParser

from kwark.command import KwarkCommand
from kwark.util import load_prompt
from kwark.ai import AI


class CommitCommand(KwarkCommand):
    """Generate a git commit message from diff output using AI.
    If there are no changes in the diff, use a dot as the commit message."""

    name = 'commit'
    prompt = load_prompt(name)

    @classmethod
    def add_args(cls, parser: WizParser):
        super().add_args(parser)
        parser.add_argument('--api-key', '-k')

    def handle_vals(self):
        super().handle_vals()
        if not self.provided('api-key'):
            if key := self.app.config.get('kwark-api-anthropic-key'):
                self.api_key = key

    @KwarkCommand.wrap
    def execute(self):
        diff_text = self.app.stream.text
        prompt = self.prompt.format(text=diff_text)
        commit_message = AI(self.api_key).query(prompt).strip()

        self.status = f"Generated commit message from diff"
        return commit_message
